#
# spec file for package nedit-ng
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nedit-ng
Version:        2019.1
Release:        1.8
Summary:        Qt port of Nirvana Editor
License:        GPL-2.0-or-later AND MIT
Group:          Productivity/Text/Editors
URL:            https://github.com/eteran/nedit-ng
Source0:        https://github.com/eteran/nedit-ng/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.changes
Source2:        %{name}.desktop
BuildRequires:  bison
BuildRequires:  cmake
%if 0%{?suse_version} >= 1500
BuildRequires:  gcc-c++
BuildRequires:  libboost_system-devel
%else
BuildRequires:  boost-devel
BuildRequires:  gcc7-c++
%endif
# SECTION docs
BuildRequires:  libqt5-qttools
BuildRequires:  python3-Jinja2
# /SECTION
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5Xml)
ExcludeArch:    %ix86 %arm ppc

%description
nedit-ng is a Qt port of the Nirvana Editor (NEdit) version 5.6.
It is intended to be a drop in replacement for nedit in every
practical way, just as on many systems /usr/bin/vi is now a symlink
to /usr/bin/vim.

Because it is a true port of the original code, it (at least for
now) inherits some (but not all) of the limitations of the original.
On the other hand, some aspects have been improved simply by the
fact that it is now a Qt application.

%prep
%setup -q

%build
test -x "$(type -p g++-7)" && export CXX=g++-7
%cmake -DBUILD_SHARED_LIBS:BOOL=OFF
make %{?_smp_mflags}

%install
%cmake_install
install -D -m0644 %{SOURCE2} %{buildroot}%{_datadir}/applications/%{name}.desktop
install -D -m0644 src/res/nedit.png %{buildroot}%{_datadir}/pixmaps/%{name}.png

%files
%license LICENSE.md
%doc README.md
%{_bindir}/nc-ng
%{_bindir}/nedit-import
%{_bindir}/nedit-ng
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png

%changelog
* Mon Jan 21 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2019.1
  * A ton of small, incremental improvements, bug fixes, and
    behavior tweaks.
* Fri Sep 14 2018 aloisio@gmx.com
- Update to version 2018.11
  * Fix an issue with paths not always having a trailing slash
  * Other misc fixes/refactorings.
* Sat Sep  1 2018 aloisio@gmx.com
- Update to version 2018.10
  * Improved color dialog
  * Fixed how permissions are checked when running as root
* Fri Aug 31 2018 aloisio@gmx.com
- Update to version 2018.9
  * Fixed build!
  version 2018.8
  * Improved line number system
  * Fixed a few minor bugs
  * Improved how X11 primary selections are handled
  * Squashed some warnings with newer compilers
  * Other misc improvements
* Wed Aug 15 2018 aloisio@gmx.com
- Update to version 2018.7
  * Improved Regex code
  * Fixed several small bugs
* Sat Aug  4 2018 aloisio@gmx.com
- Update to version 2018.6
  * Lots of small improvements and bug fixes
  * Fixed an issue where the exit button in one specific case did
    not work
  * Added an advanced setting to have nedit-ng display the
    dimensions of the edit area in characters upon resize
* Thu Jul 12 2018 aloisio@gmx.com
- Update to version 2018.5
  * Improved the simplicity and efficiency of font support
  * Popups launched in scripts are no longer modal (like classic
    NEdit)
  * Find/Replace now properly get focus
  * Fixed several small bugs
  * Much more ...
* Fri Apr 13 2018 aloisio@gmx.com
- Update to version 2018.4
  * Fixed a rare crash with large forward lookaheads in regex
    engine
  * Fixed an issue where some command line arguments were not
    properly being relayed from nc-ng to nedit-ng in server mode
  * Fixed issue where Qt has been filtering -geometry from argv
  * A few modernizations of the code
* Wed Apr 11 2018 aloisio@gmx.com
- Update to version 2018.3
  * Lots of small changes for code quality
  * Big performance improvement when using fixed width fonts
  * Misc bug fixes
  * Fixed issue with settings importing for the first time
  * Started French translation (not complete yet)
  * More strings are translatable now
  * Using Native printer support
* Thu Feb 22 2018 aloisio@gmx.com
- Update to version 2018.2 (no changelog supplied)
* Wed Jan 31 2018 aloisio@gmx.com
- Initial package (2018.1)
